@@ -7,7 +7,7 @@ import pointofview
 from prosegrinder.dictionary import Dictionary
 
 
-class FragmentContainer():
+class FragmentContainer(object):
 
     def __init__(self, fragments, dictionary=Dictionary()):
         self._dictionary = dictionary
@@ -31,9 +31,15 @@ class FragmentContainer():
         self._third_person_word_count = sum(
             [fragment.third_person_word_count for fragment in self._fragments])
         wf = Counter()
+        pf = Counter()
+        pc = 0
         for fragment in self._fragments:
             wf.update(fragment.words)
+            pf.update(fragment.phone_frequency)
+            pc += fragment.phone_count
         self._word_frequency = dict(wf)
+        self._phone_frequency = dict(pf)
+        self._phone_count = pc
         self._pov = pointofview.NONE
         if (self._first_person_word_count > 0):
             self._pov = pointofview.FIRST
@@ -42,9 +48,6 @@ class FragmentContainer():
         elif (self._third_person_word_count > 0):
             self._pov = pointofview.THIRD
 
-    def __str__(self):
-        return str(self.__dict__)
-
     def __eq__(self, other):
         return self._fragments == other._fragments
 
@@ -55,6 +58,14 @@ class FragmentContainer():
     def dictionary(self):
         return self._dictionary
 
+    @property
+    def phone_frequency(self):
+        return self._phone_frequency
+
+    @property
+    def phone_count(self):
+        return self._phone_count
+
     @property
     def word_count(self):
         return self._word_count
