@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 
 from collections import Counter
+import hashlib
 
 import narrative
 
@@ -11,10 +12,11 @@ from prosegrinder.paragraph import Paragraph
 from prosegrinder.readability_scores import ReadabilityScores
 
 
-class Prose():
+class Prose(object):
 
     def __init__(self, text, dictionary=Dictionary()):
         self._text = text
+        self._sha256 = hashlib.sha256(self._text.encode()).hexdigest()
         self._dictionary = dictionary
         self._paragraphs = Paragraph.parse_paragraphs(
             self._text, self._dictionary)
@@ -37,9 +39,15 @@ class Prose():
         self._third_person_word_count = sum(
             [paragraph.third_person_word_count for paragraph in self._paragraphs])
         wf = Counter()
+        pf = Counter()
+        pc = 0
         for paragraph in self._paragraphs:
             wf.update(paragraph.word_frequency)
+            pf.update(paragraph.phone_frequency)
+            pc += paragraph.phone_count
         self._word_frequency = dict(wf)
+        self._phone_frequency = dict(pf)
+        self._phone_count = pc
         self._sentence_count = sum(
             [paragraph.sentence_count for paragraph in self._paragraphs])
         self._paragraph_count = len(self._paragraphs)
@@ -53,9 +61,6 @@ class Prose():
             [Fragment(fragment_text) for fragment_text in n['narrative']])
         self._pov = self._narrative.pov
 
-    def __str__(self):
-        return str(self.__dict__)
-
     def __eq__(self, other):
         return self._text == other._text
 
@@ -66,6 +71,14 @@ class Prose():
     def dictionary(self):
         return self._dictionary
 
+    @property
+    def phone_frequency(self):
+        return self._phone_frequency
+
+    @property
+    def phone_count(self):
+        return self._phone_count
+
     @property
     def word_character_count(self):
         return self._word_character_count
@@ -111,7 +124,7 @@ class Prose():
         return self._sentence_count
 
     @property
-    def paragrah_count(self):
+    def paragraph_count(self):
         return self._paragraph_count
 
     @property
@@ -133,3 +146,7 @@ class Prose():
     @property
     def text(self):
         return self._text
+
+    @property
+    def sha256(self):
+        return self._sha256
