@@ -12,6 +12,7 @@ text = open(SHORTSTORY).read()
 prose = Prose(text)
 
 WORD_CHARACTER_COUNT = 7008
+PHONE_COUNT = 5747
 SYLLABLE_COUNT = 2287
 COMPLEX_WORD_COUNT = 202
 LONG_WORD_COUNT = 275
@@ -38,6 +39,10 @@ def test_characters():
     assert(WORD_CHARACTER_COUNT == prose.word_character_count)
 
 
+def test_phones():
+    assert(PHONE_COUNT == prose.phone_count)
+
+
 def test_syllables():
     assert(SYLLABLE_COUNT == prose.syllable_count)
 
@@ -61,7 +66,7 @@ def test_sentences():
 
 
 def test_paragraphs():
-    assert(PARAGRAPH_COUNT == prose.paragrah_count)
+    assert(PARAGRAPH_COUNT == prose.paragraph_count)
 
 
 def test_dialogue_narrative():
